from enum import Enum

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.items import Items

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetTrashedItemsDirection(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class GetTrashedItemsSort(str, Enum):
    NAME = 'name'
    DATE = 'date'
    SIZE = 'size'


class TrashedItemsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_trashed_items(
        self,
        *,
        fields: Optional[List[str]] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        usemarker: Optional[bool] = None,
        marker: Optional[str] = None,
        direction: Optional[GetTrashedItemsDirection] = None,
        sort: Optional[GetTrashedItemsSort] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Items:
        """
                Retrieves the files and folders that have been moved

                to the trash.


                Any attribute in the full files or folders objects can be passed


                in with the `fields` parameter to retrieve those specific


                attributes that are not returned by default.


                This endpoint defaults to use offset-based pagination, yet also supports


                marker-based pagination using the `marker` parameter.

                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param usemarker: Specifies whether to use marker-based pagination instead of
        offset-based pagination. Only one pagination method can
        be used at a time.

        By setting this value to true, the API will return a `marker` field
        that can be passed as a parameter to this endpoint to get the next
        page of the response., defaults to None
                :type usemarker: Optional[bool], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param direction: The direction to sort results in. This can be either in alphabetical ascending
        (`ASC`) or descending (`DESC`) order., defaults to None
                :type direction: Optional[GetTrashedItemsDirection], optional
                :param sort: Defines the **second** attribute by which items
        are sorted.

        Items are always sorted by their `type` first, with
        folders listed before files, and files listed
        before web links.

        This parameter is not supported when using marker-based pagination., defaults to None
                :type sort: Optional[GetTrashedItemsSort], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'fields': to_string(fields),
                'limit': to_string(limit),
                'offset': to_string(offset),
                'usemarker': to_string(usemarker),
                'marker': to_string(marker),
                'direction': to_string(direction),
                'sort': to_string(sort),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/trash/items',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Items)



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class FolderReferenceV2025R0TypeField(str, Enum):
    FOLDER = 'folder'


class FolderReferenceV2025R0(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        *,
        type: FolderReferenceV2025R0TypeField = FolderReferenceV2025R0TypeField.FOLDER,
        **kwargs
    ):
        """
        :param id: ID of the folder.
        :type id: str
        :param type: The value will always be `folder`., defaults to FolderReferenceV2025R0TypeField.FOLDER
        :type type: FolderReferenceV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseBaseTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class EnterpriseBase(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[EnterpriseBaseTypeField] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[EnterpriseBaseTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.metadata_cascade_policies import MetadataCascadePolicies

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.metadata_cascade_policy import MetadataCascadePolicy

from box_sdk_gen.schemas.conflict_error import ConflictError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateMetadataCascadePolicyScope(str, Enum):
    GLOBAL = 'global'
    ENTERPRISE = 'enterprise'


class ApplyMetadataCascadePolicyConflictResolution(str, Enum):
    NONE = 'none'
    OVERWRITE = 'overwrite'


class MetadataCascadePoliciesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_metadata_cascade_policies(
        self,
        folder_id: str,
        *,
        owner_enterprise_id: Optional[str] = None,
        marker: Optional[str] = None,
        offset: Optional[int] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataCascadePolicies:
        """
                Retrieves a list of all the metadata cascade policies

                that are applied to a given folder. This can not be used on the root


                folder with ID `0`.

                :param folder_id: Specifies which folder to return policies for. This can not be used on the
        root folder with ID `0`.
                :type folder_id: str
                :param owner_enterprise_id: The ID of the enterprise ID for which to find metadata
        cascade policies. If not specified, it defaults to the
        current enterprise., defaults to None
                :type owner_enterprise_id: Optional[str], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param offset: The offset of the item at which to begin the response.

        Queries with offset parameter value
        exceeding 10000 will be rejected
        with a 400 response., defaults to None
                :type offset: Optional[int], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'folder_id': to_string(folder_id),
                'owner_enterprise_id': to_string(owner_enterprise_id),
                'marker': to_string(marker),
                'offset': to_string(offset),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_cascade_policies',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataCascadePolicies)

    def create_metadata_cascade_policy(
        self,
        folder_id: str,
        scope: CreateMetadataCascadePolicyScope,
        template_key: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataCascadePolicy:
        """
                Creates a new metadata cascade policy that applies a given

                metadata template to a given folder and automatically


                cascades it down to any files within that folder.


                In order for the policy to be applied a metadata instance must first


                be applied to the folder the policy is to be applied to.

                :param folder_id: The ID of the folder to apply the policy to. This folder will
        need to already have an instance of the targeted metadata
        template applied to it.
                :type folder_id: str
                :param scope: The scope of the targeted metadata template. This template will
        need to already have an instance applied to the targeted folder.
                :type scope: CreateMetadataCascadePolicyScope
                :param template_key: The key of the targeted metadata template. This template will
        need to already have an instance applied to the targeted folder.

        In many cases the template key is automatically derived
        of its display name, for example `Contract Template` would
        become `contractTemplate`. In some cases the creator of the
        template will have provided its own template key.

        Please [list the templates for an enterprise][list], or
        get all instances on a [file][file] or [folder][folder]
        to inspect a template's key.

        [list]: https://developer.box.com/reference/get-metadata-templates-enterprise
        [file]: https://developer.box.com/reference/get-files-id-metadata
        [folder]: https://developer.box.com/reference/get-folders-id-metadata
                :type template_key: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'folder_id': folder_id,
            'scope': scope,
            'templateKey': template_key,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_cascade_policies',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataCascadePolicy)

    def get_metadata_cascade_policy_by_id(
        self,
        metadata_cascade_policy_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataCascadePolicy:
        """
                Retrieve a specific metadata cascade policy assigned to a folder.
                :param metadata_cascade_policy_id: The ID of the metadata cascade policy.
        Example: "6fd4ff89-8fc1-42cf-8b29-1890dedd26d7"
                :type metadata_cascade_policy_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_cascade_policies/',
                        to_string(metadata_cascade_policy_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataCascadePolicy)

    def delete_metadata_cascade_policy_by_id(
        self,
        metadata_cascade_policy_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a metadata cascade policy.
                :param metadata_cascade_policy_id: The ID of the metadata cascade policy.
        Example: "6fd4ff89-8fc1-42cf-8b29-1890dedd26d7"
                :type metadata_cascade_policy_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_cascade_policies/',
                        to_string(metadata_cascade_policy_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def apply_metadata_cascade_policy(
        self,
        metadata_cascade_policy_id: str,
        conflict_resolution: ApplyMetadataCascadePolicyConflictResolution,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Force the metadata on a folder with a metadata cascade policy to be applied to

                all of its children. This can be used after creating a new cascade policy to


                enforce the metadata to be cascaded down to all existing files within that


                folder.

                :param metadata_cascade_policy_id: The ID of the cascade policy to force-apply.
        Example: "6fd4ff89-8fc1-42cf-8b29-1890dedd26d7"
                :type metadata_cascade_policy_id: str
                :param conflict_resolution: Describes the desired behavior when dealing with the conflict
        where a metadata template already has an instance applied
        to a child.

        * `none` will preserve the existing value on the file
        * `overwrite` will force-apply the templates values over
          any existing values.
                :type conflict_resolution: ApplyMetadataCascadePolicyConflictResolution
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'conflict_resolution': conflict_resolution}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/metadata_cascade_policies/',
                        to_string(metadata_cascade_policy_id),
                        '/apply',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError


class CollaboratorVariableTypeField(str, Enum):
    VARIABLE = 'variable'


class CollaboratorVariableVariableTypeField(str, Enum):
    USER_LIST = 'user_list'


class CollaboratorVariableVariableValueTypeField(str, Enum):
    USER = 'user'


class CollaboratorVariableVariableValueField(BaseObject):
    _discriminator = 'type', {'user'}

    def __init__(
        self,
        id: str,
        *,
        type: CollaboratorVariableVariableValueTypeField = CollaboratorVariableVariableValueTypeField.USER,
        **kwargs
    ):
        """
        :param id: User's ID.
        :type id: str
        :param type: The object type., defaults to CollaboratorVariableVariableValueTypeField.USER
        :type type: CollaboratorVariableVariableValueTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CollaboratorVariable(BaseObject):
    _discriminator = 'type', {'variable'}

    def __init__(
        self,
        variable_value: List[CollaboratorVariableVariableValueField],
        *,
        type: CollaboratorVariableTypeField = CollaboratorVariableTypeField.VARIABLE,
        variable_type: CollaboratorVariableVariableTypeField = CollaboratorVariableVariableTypeField.USER_LIST,
        **kwargs
    ):
        """
                :param variable_value: A list of user IDs.
                :type variable_value: List[CollaboratorVariableVariableValueField]
                :param type: Collaborator
        object type., defaults to CollaboratorVariableTypeField.VARIABLE
                :type type: CollaboratorVariableTypeField, optional
                :param variable_type: Variable type
        for the Collaborator
        object., defaults to CollaboratorVariableVariableTypeField.USER_LIST
                :type variable_type: CollaboratorVariableVariableTypeField, optional
        """
        super().__init__(**kwargs)
        self.variable_value = variable_value
        self.type = type
        self.variable_type = variable_type



from typing import Optional

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from typing import List

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenGrantTypeField

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenSubjectTokenTypeField

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.schemas.access_token import AccessToken

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2Token

from box_sdk_gen.schemas.post_o_auth_2_revoke import PostOAuth2Revoke

from box_sdk_gen.managers.authorization import AuthorizationManager

from box_sdk_gen.box.token_storage import TokenStorage

from box_sdk_gen.box.token_storage import InMemoryTokenStorage

from box_sdk_gen.serialization.json import sd_to_url_params

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.serialization.json import SerializedData


class OAuthConfig:
    def __init__(
        self, client_id: str, client_secret: str, *, token_storage: TokenStorage = None
    ):
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        self.client_id = client_id
        self.client_secret = client_secret
        self.token_storage = token_storage


class GetAuthorizeUrlOptions:
    def __init__(
        self,
        *,
        client_id: Optional[str] = None,
        redirect_uri: Optional[str] = None,
        response_type: Optional[str] = None,
        state: Optional[str] = None,
        scope: Optional[str] = None
    ):
        """
        :param client_id: Box API key used for identifying the application the user is authenticating with, defaults to None
        :type client_id: Optional[str], optional
        :param redirect_uri: The URI to which Box redirects the browser after the user has granted or denied the application permission. This URI match one of the redirect URIs in the configuration of your application., defaults to None
        :type redirect_uri: Optional[str], optional
        :param response_type: The type of response we would like to receive., defaults to None
        :type response_type: Optional[str], optional
        :param state: A custom string of your choice. Box will pass the same string to the redirect URL when authentication is complete. This parameter can be used to identify a user on redirect, as well as protect against hijacked sessions and other exploits., defaults to None
        :type state: Optional[str], optional
        :param scope: A space-separated list of application scopes you'd like to authenticate the user for. This defaults to all the scopes configured for the application in its configuration page., defaults to None
        :type scope: Optional[str], optional
        """
        self.client_id = client_id
        self.redirect_uri = redirect_uri
        self.response_type = response_type
        self.state = state
        self.scope = scope


class BoxOAuth(Authentication):
    def __init__(self, config: OAuthConfig, **kwargs):
        """
        :param config: Configuration object of OAuth.
        :type config: OAuthConfig
        """
        super().__init__(**kwargs)
        self.config = config
        self.token_storage = self.config.token_storage

    def get_authorize_url(self, *, options: GetAuthorizeUrlOptions = None) -> str:
        """
        Get the authorization URL for the app user.
        """
        if options is None:
            options = GetAuthorizeUrlOptions()
        params_map: Dict[str, str] = prepare_params(
            {
                'client_id': (
                    options.client_id
                    if not options.client_id == None
                    else self.config.client_id
                ),
                'response_type': (
                    options.response_type
                    if not options.response_type == None
                    else 'code'
                ),
                'redirect_uri': options.redirect_uri,
                'state': options.state,
                'scope': options.scope,
            }
        )
        return ''.join(
            [
                'https://account.box.com/api/oauth2/authorize?',
                sd_to_url_params(serialize(params_map)),
            ]
        )

    def get_tokens_authorization_code_grant(
        self,
        authorization_code: str,
        *,
        network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Acquires token info using an authorization code.
        :param authorization_code: The authorization code to use to get tokens.
        :type authorization_code: str
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.AUTHORIZATION_CODE,
            code=authorization_code,
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
        )
        self.token_storage.store(token)
        return token

    def retrieve_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Get the current access token. If the current access token is expired or not found, this method will attempt to refresh the token.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.token_storage.get()
        if token == None:
            raise BoxSDKError(
                message='Access and refresh tokens not available. Authenticate before making any API call first.'
            )
        return token

    def refresh_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Get a new access token for the platform app user.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        old_token: Optional[AccessToken] = self.token_storage.get()
        token_used_for_refresh: Optional[str] = (
            old_token.refresh_token if not old_token == None else None
        )
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.REFRESH_TOKEN,
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            refresh_token=token_used_for_refresh,
        )
        self.token_storage.store(token)
        return token

    def retrieve_authorization_header(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> str:
        token: AccessToken = self.retrieve_token(network_session=network_session)
        return ''.join(['Bearer ', token.access_token])

    def revoke_token(self, *, network_session: Optional[NetworkSession] = None) -> None:
        """
        Revoke an active Access Token, effectively logging a user out that has been previously authenticated.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.token_storage.get()
        if token == None:
            return None
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        auth_manager.revoke_access_token(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            token=token.access_token,
        )
        return None

    def downscope_token(
        self,
        scopes: List[str],
        *,
        resource: Optional[str] = None,
        shared_link: Optional[str] = None,
        network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Downscope access token to the provided scopes. Returning a new access token with the provided scopes, with the original access token unchanged.
        :param scopes: The scope(s) to apply to the resulting token.
        :type scopes: List[str]
        :param resource: The file or folder to get a downscoped token for. If None and shared_link None, the resulting token will not be scoped down to just a single item. The resource should be a full URL to an item, e.g. https://api.box.com/2.0/files/123456., defaults to None
        :type resource: Optional[str], optional
        :param shared_link: The shared link to get a downscoped token for. If None and item None, the resulting token will not be scoped down to just a single item., defaults to None
        :type shared_link: Optional[str], optional
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.retrieve_token(
            network_session=network_session
        )
        if token == None or token.access_token == None:
            raise BoxSDKError(message='No access token is available.')
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        downscoped_token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.URN_IETF_PARAMS_OAUTH_GRANT_TYPE_TOKEN_EXCHANGE,
            subject_token=token.access_token,
            subject_token_type=PostOAuth2TokenSubjectTokenTypeField.URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ACCESS_TOKEN,
            resource=resource,
            scope=' '.join(scopes),
            box_shared_link=shared_link,
        )
        return downscoped_token



from datetime import datetime, date
from enum import EnumMeta, Enum
from typing import get_args, get_origin, Union, Optional
from .null_value import NullValue


class BaseObject:
    _discriminator = (None, {})
    _json_to_fields_mapping = {}
    _fields_to_json_mapping = {}

    def __init__(self, **kwargs):
        self._raw_data: dict = {}
        self.__dict__.update(kwargs)

    @classmethod
    def from_dict(cls, data: dict):
        unpacked_attributes = {}
        for key, value in data.items():
            mapping_field_name = cls._json_to_fields_mapping.get(key, key)
            annotation = cls.__init__.__annotations__.get(mapping_field_name, None)
            unpacked_attributes[mapping_field_name] = cls._deserialize(
                key, value, annotation
            )
        return cls(**unpacked_attributes)

    @property
    def raw_data(self):
        """
        Returns the raw json representation returned by the API
        :return: dict with the raw json data
        """
        return self._raw_data

    def to_dict(self) -> dict:
        result_dict = {}
        for k, v in vars(self).items():
            # Skip private and protected attributes
            if k.startswith("_"):
                continue
            if v is None:
                continue
            if isinstance(v, NullValue):
                value = None
            elif type(v) is list:
                value = [
                    item.to_dict() if isinstance(item, BaseObject) else item
                    for item in v
                ]
            elif type(v) is dict:
                value = {
                    key: value.to_dict() if isinstance(value, BaseObject) else value
                    for key, value in v.items()
                }
            elif isinstance(v, BaseObject):
                value = v.to_dict()
            elif isinstance(v, Enum):
                value = v.value
            elif isinstance(v, date):
                value = v.isoformat()
            elif isinstance(v, datetime):
                value = v.isoformat().replace('+00:00', 'Z')
            else:
                value = v
            result_dict[self._fields_to_json_mapping.get(k, k)] = value

        return result_dict

    @classmethod
    def _deserialize(cls, key, value, annotation=None):
        if annotation is None or value is None:
            return value
        if get_origin(annotation) == Optional:
            return cls._deserialize(key, value, get_args(annotation))
        if get_origin(annotation) == Union:
            union_without_none_type = [
                arg for arg in get_args(annotation) if arg is not type(None)
            ]
            if len(union_without_none_type) == 1:
                return cls._deserialize(key, value, union_without_none_type[0])

        if get_origin(annotation) == list:
            return cls._deserialize_list(key, value, annotation)
        elif get_origin(annotation) == Union:
            return cls._deserialize_union(key, value, annotation)
        elif isinstance(annotation, EnumMeta):
            return cls._deserialize_enum(key, value, annotation)
        elif annotation == datetime:
            return cls._deserialize_datetime(key, value, annotation)
        elif annotation == date:
            return cls._deserialize_date(key, value, annotation)
        elif isinstance(annotation, type) and issubclass(annotation, BaseObject):
            return cls._deserialize_nested_type(key, value, annotation)
        else:
            return value

    @classmethod
    def _deserialize_list(cls, key, value, annotation: list):
        try:
            list_type = get_args(annotation)[0]
            return [
                cls._deserialize(key, list_entry, list_type) for list_entry in value
            ]
        except Exception:
            return value

    @classmethod
    def _deserialize_union(cls, key, value, annotation):
        try:
            possible_types = get_args(annotation)
            if value is None:
                if type(None) not in possible_types:
                    print(
                        'Value: ', value, 'should not be allowed in Union:', annotation
                    )
                return value

            for possible_type in possible_types:
                if (
                    isinstance(possible_type, type)
                    and issubclass(possible_type, BaseObject)
                    and value.get(possible_type._discriminator[0], None)
                    in possible_type._discriminator[1]
                ):
                    return cls._deserialize(key, value, possible_type)

            for possible_type in possible_types:
                try:
                    return cls._deserialize(key, value, possible_type)
                except Exception:
                    continue
            return value
        except Exception:
            return value

    @classmethod
    def _deserialize_enum(cls, key, value, annotation):
        try:
            return getattr(annotation, value.upper().replace(' ', '_'))
        except Exception:
            return value

    @classmethod
    def _deserialize_datetime(cls, key, value, annotation):
        try:
            return datetime.fromisoformat(value.replace('Z', '+00:00'))
        except Exception:
            return value

    @classmethod
    def _deserialize_date(cls, key, value, annotation):
        try:
            return date.fromisoformat(value)
        except Exception:
            return value

    @classmethod
    def _deserialize_nested_type(cls, key, value, annotation):
        try:
            return annotation.from_dict(value)
        except Exception:
            return value

    def __repr__(self) -> str:
        return f'{self.__class__} {self.to_dict()}'



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class CollaborationPermissionsV2025R0(BaseObject):
    def __init__(
        self,
        *,
        is_co_owner_role_enabled: Optional[bool] = None,
        is_editor_role_enabled: Optional[bool] = None,
        is_previewer_role_enabled: Optional[bool] = None,
        is_previewer_uploader_role_enabled: Optional[bool] = None,
        is_uploader_role_enabled: Optional[bool] = None,
        is_viewer_role_enabled: Optional[bool] = None,
        is_viewer_uploader_role_enabled: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_co_owner_role_enabled: The co-owner role is enabled for collaboration., defaults to None
        :type is_co_owner_role_enabled: Optional[bool], optional
        :param is_editor_role_enabled: The editor role is enabled for collaboration., defaults to None
        :type is_editor_role_enabled: Optional[bool], optional
        :param is_previewer_role_enabled: The previewer role is enabled for collaboration., defaults to None
        :type is_previewer_role_enabled: Optional[bool], optional
        :param is_previewer_uploader_role_enabled: The previewer uploader role is enabled for collaboration., defaults to None
        :type is_previewer_uploader_role_enabled: Optional[bool], optional
        :param is_uploader_role_enabled: The uploader role is enabled for collaboration., defaults to None
        :type is_uploader_role_enabled: Optional[bool], optional
        :param is_viewer_role_enabled: The viewer role is enabled for collaboration., defaults to None
        :type is_viewer_role_enabled: Optional[bool], optional
        :param is_viewer_uploader_role_enabled: The viewer uploader role is enabled for collaboration., defaults to None
        :type is_viewer_uploader_role_enabled: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.is_co_owner_role_enabled = is_co_owner_role_enabled
        self.is_editor_role_enabled = is_editor_role_enabled
        self.is_previewer_role_enabled = is_previewer_role_enabled
        self.is_previewer_uploader_role_enabled = is_previewer_uploader_role_enabled
        self.is_uploader_role_enabled = is_uploader_role_enabled
        self.is_viewer_role_enabled = is_viewer_role_enabled
        self.is_viewer_uploader_role_enabled = is_viewer_uploader_role_enabled



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.ai_studio_agent_basic_gen_tool import AiStudioAgentBasicGenTool

from box_sdk_gen.box.errors import BoxSDKError


class AiStudioAgentTextGenTypeField(str, Enum):
    AI_AGENT_TEXT_GEN = 'ai_agent_text_gen'


class AiStudioAgentTextGen(BaseObject):
    _discriminator = 'type', {'ai_agent_text_gen'}

    def __init__(
        self,
        access_state: str,
        description: str,
        *,
        type: AiStudioAgentTextGenTypeField = AiStudioAgentTextGenTypeField.AI_AGENT_TEXT_GEN,
        custom_instructions: Optional[str] = None,
        suggested_questions: Optional[List[str]] = None,
        basic_gen: Optional[AiStudioAgentBasicGenTool] = None,
        **kwargs
    ):
        """
        :param access_state: The state of the AI Agent capability. Possible values are: `enabled` and `disabled`.
        :type access_state: str
        :param description: The description of the AI agent.
        :type description: str
        :param type: The type of AI agent used for generating text., defaults to AiStudioAgentTextGenTypeField.AI_AGENT_TEXT_GEN
        :type type: AiStudioAgentTextGenTypeField, optional
        :param custom_instructions: Custom instructions for the AI agent., defaults to None
        :type custom_instructions: Optional[str], optional
        :param suggested_questions: Suggested questions for the AI agent. If null, suggested question will be generated. If empty, no suggested questions will be displayed., defaults to None
        :type suggested_questions: Optional[List[str]], optional
        """
        super().__init__(**kwargs)
        self.access_state = access_state
        self.description = description
        self.type = type
        self.custom_instructions = custom_instructions
        self.suggested_questions = suggested_questions
        self.basic_gen = basic_gen



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.sign_request_prefill_tag import SignRequestPrefillTag

from box_sdk_gen.schemas.sign_request_base import SignRequestBase

from box_sdk_gen.schemas.file_base import FileBase

from box_sdk_gen.schemas.sign_request_signer import SignRequestSigner

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class SignRequestTypeField(str, Enum):
    SIGN_REQUEST = 'sign-request'


class SignRequestStatusField(str, Enum):
    CONVERTING = 'converting'
    CREATED = 'created'
    SENT = 'sent'
    VIEWED = 'viewed'
    SIGNED = 'signed'
    CANCELLED = 'cancelled'
    DECLINED = 'declined'
    ERROR_CONVERTING = 'error_converting'
    ERROR_SENDING = 'error_sending'
    EXPIRED = 'expired'
    FINALIZING = 'finalizing'
    ERROR_FINALIZING = 'error_finalizing'


class SignRequestSignFilesField(BaseObject):
    def __init__(
        self,
        *,
        files: Optional[List[FileMini]] = None,
        is_ready_for_download: Optional[bool] = None,
        **kwargs
    ):
        """
                :param is_ready_for_download: Indicates whether the `sign_files` documents are processing
        and the PDFs may be out of date. A change to any document
        requires processing on all `sign_files`. We
        recommended waiting until processing is finished
        (and this value is true) before downloading the PDFs., defaults to None
                :type is_ready_for_download: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.files = files
        self.is_ready_for_download = is_ready_for_download


class SignRequest(SignRequestBase):
    def __init__(
        self,
        *,
        type: Optional[SignRequestTypeField] = None,
        source_files: Optional[List[FileBase]] = None,
        signers: Optional[List[SignRequestSigner]] = None,
        signature_color: Optional[str] = None,
        id: Optional[str] = None,
        prepare_url: Optional[str] = None,
        signing_log: Optional[FileMini] = None,
        status: Optional[SignRequestStatusField] = None,
        sign_files: Optional[SignRequestSignFilesField] = None,
        auto_expire_at: Optional[DateTime] = None,
        parent_folder: Optional[FolderMini] = None,
        collaborator_level: Optional[str] = None,
        short_id: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        finished_at: Optional[DateTime] = None,
        sender_email: Optional[str] = None,
        sender_id: Optional[int] = None,
        is_document_preparation_needed: Optional[bool] = None,
        redirect_url: Optional[str] = None,
        declined_redirect_url: Optional[str] = None,
        are_text_signatures_enabled: Optional[bool] = None,
        email_subject: Optional[str] = None,
        email_message: Optional[str] = None,
        are_reminders_enabled: Optional[bool] = None,
        name: Optional[str] = None,
        prefill_tags: Optional[List[SignRequestPrefillTag]] = None,
        days_valid: Optional[int] = None,
        external_id: Optional[str] = None,
        template_id: Optional[str] = None,
        external_system_name: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `sign-request`., defaults to None
                :type type: Optional[SignRequestTypeField], optional
                :param source_files: List of files to create a signing document from. This is currently limited to ten files. Only the ID and type fields are required for each file., defaults to None
                :type source_files: Optional[List[FileBase]], optional
                :param signers: Array of signers for the signature request., defaults to None
                :type signers: Optional[List[SignRequestSigner]], optional
                :param signature_color: Force a specific color for the signature (blue, black, or red)., defaults to None
                :type signature_color: Optional[str], optional
                :param id: Box Sign request ID., defaults to None
                :type id: Optional[str], optional
                :param prepare_url: This URL is returned if `is_document_preparation_needed` is
        set to `true` in the request. The parameter is used to prepare
        the signature request
        using the UI. The signature request is not
        sent until the preparation
        phase is complete., defaults to None
                :type prepare_url: Optional[str], optional
                :param status: Describes the status of the signature request., defaults to None
                :type status: Optional[SignRequestStatusField], optional
                :param sign_files: List of files that will be signed, which are copies of the original
        source files. A new version of these files are created as signers sign
        and can be downloaded at any point in the signing process., defaults to None
                :type sign_files: Optional[SignRequestSignFilesField], optional
                :param auto_expire_at: Uses `days_valid` to calculate the date and time, in GMT, the sign request will expire if unsigned., defaults to None
                :type auto_expire_at: Optional[DateTime], optional
                :param collaborator_level: The collaborator level of the user to the sign request. Values can include "owner", "editor", and "viewer"., defaults to None
                :type collaborator_level: Optional[str], optional
                :param short_id: Short identifier for the sign request., defaults to None
                :type short_id: Optional[str], optional
                :param created_at: Timestamp marking when the sign request was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param finished_at: Timestamp indicating when all signing actions completed., defaults to None
                :type finished_at: Optional[DateTime], optional
                :param sender_email: The email address of the sender of the sign request., defaults to None
                :type sender_email: Optional[str], optional
                :param sender_id: The user ID of the sender of the sign request., defaults to None
                :type sender_id: Optional[int], optional
                :param is_document_preparation_needed: Indicates if the sender should receive a `prepare_url` in the response to complete document preparation using the UI., defaults to None
                :type is_document_preparation_needed: Optional[bool], optional
                :param redirect_url: When specified, the signature request will be redirected to this url when a document is signed., defaults to None
                :type redirect_url: Optional[str], optional
                :param declined_redirect_url: The uri that a signer will be redirected to after declining to sign a document., defaults to None
                :type declined_redirect_url: Optional[str], optional
                :param are_text_signatures_enabled: Disables the usage of signatures generated by typing (text)., defaults to None
                :type are_text_signatures_enabled: Optional[bool], optional
                :param email_subject: Subject of sign request email. This is cleaned by sign request. If this field is not passed, a default subject will be used., defaults to None
                :type email_subject: Optional[str], optional
                :param email_message: Message to include in sign request email. The field is cleaned through sanitization of specific characters. However, some html tags are allowed. Links included in the message are also converted to hyperlinks in the email. The message may contain the following html tags including `a`, `abbr`, `acronym`, `b`, `blockquote`, `code`, `em`, `i`, `ul`, `li`, `ol`, and `strong`. Be aware that when the text to html ratio is too high, the email may end up in spam filters. Custom styles on these tags are not allowed. If this field is not passed, a default message will be used., defaults to None
                :type email_message: Optional[str], optional
                :param are_reminders_enabled: Reminds signers to sign a document on day 3, 8, 13 and 18. Reminders are only sent to outstanding signers., defaults to None
                :type are_reminders_enabled: Optional[bool], optional
                :param name: Name of the signature request., defaults to None
                :type name: Optional[str], optional
                :param prefill_tags: When a document contains sign-related tags in the content, you can prefill them using this `prefill_tags` by referencing the 'id' of the tag as the `external_id` field of the prefill tag., defaults to None
                :type prefill_tags: Optional[List[SignRequestPrefillTag]], optional
                :param days_valid: Set the number of days after which the created signature request will automatically expire if not completed. By default, we do not apply any expiration date on signature requests, and the signature request does not expire., defaults to None
                :type days_valid: Optional[int], optional
                :param external_id: This can be used to reference an ID in an external system that the sign request is related to., defaults to None
                :type external_id: Optional[str], optional
                :param template_id: When a signature request is created from a template this field will indicate the id of that template., defaults to None
                :type template_id: Optional[str], optional
                :param external_system_name: Used as an optional system name to appear in the signature log next to the signers who have been assigned the `embed_url_external_id`., defaults to None
                :type external_system_name: Optional[str], optional
        """
        super().__init__(
            is_document_preparation_needed=is_document_preparation_needed,
            redirect_url=redirect_url,
            declined_redirect_url=declined_redirect_url,
            are_text_signatures_enabled=are_text_signatures_enabled,
            email_subject=email_subject,
            email_message=email_message,
            are_reminders_enabled=are_reminders_enabled,
            name=name,
            prefill_tags=prefill_tags,
            days_valid=days_valid,
            external_id=external_id,
            template_id=template_id,
            external_system_name=external_system_name,
            **kwargs
        )
        self.type = type
        self.source_files = source_files
        self.signers = signers
        self.signature_color = signature_color
        self.id = id
        self.prepare_url = prepare_url
        self.signing_log = signing_log
        self.status = status
        self.sign_files = sign_files
        self.auto_expire_at = auto_expire_at
        self.parent_folder = parent_folder
        self.collaborator_level = collaborator_level
        self.short_id = short_id
        self.created_at = created_at
        self.finished_at = finished_at
        self.sender_email = sender_email
        self.sender_id = sender_id



from typing import Dict

from box_sdk_gen.managers.authorization import AuthorizationManager

from box_sdk_gen.managers.files import FilesManager

from box_sdk_gen.managers.trashed_files import TrashedFilesManager

from box_sdk_gen.managers.app_item_associations import AppItemAssociationsManager

from box_sdk_gen.managers.downloads import DownloadsManager

from box_sdk_gen.managers.uploads import UploadsManager

from box_sdk_gen.managers.chunked_uploads import ChunkedUploadsManager

from box_sdk_gen.managers.list_collaborations import ListCollaborationsManager

from box_sdk_gen.managers.comments import CommentsManager

from box_sdk_gen.managers.tasks import TasksManager

from box_sdk_gen.managers.file_versions import FileVersionsManager

from box_sdk_gen.managers.file_metadata import FileMetadataManager

from box_sdk_gen.managers.file_classifications import FileClassificationsManager

from box_sdk_gen.managers.skills import SkillsManager

from box_sdk_gen.managers.file_watermarks import FileWatermarksManager

from box_sdk_gen.managers.file_requests import FileRequestsManager

from box_sdk_gen.managers.folders import FoldersManager

from box_sdk_gen.managers.trashed_folders import TrashedFoldersManager

from box_sdk_gen.managers.folder_metadata import FolderMetadataManager

from box_sdk_gen.managers.folder_classifications import FolderClassificationsManager

from box_sdk_gen.managers.trashed_items import TrashedItemsManager

from box_sdk_gen.managers.folder_watermarks import FolderWatermarksManager

from box_sdk_gen.managers.folder_locks import FolderLocksManager

from box_sdk_gen.managers.metadata_templates import MetadataTemplatesManager

from box_sdk_gen.managers.classifications import ClassificationsManager

from box_sdk_gen.managers.metadata_cascade_policies import (
    MetadataCascadePoliciesManager,
)

from box_sdk_gen.managers.search import SearchManager

from box_sdk_gen.managers.user_collaborations import UserCollaborationsManager

from box_sdk_gen.managers.task_assignments import TaskAssignmentsManager

from box_sdk_gen.managers.shared_links_files import SharedLinksFilesManager

from box_sdk_gen.managers.shared_links_folders import SharedLinksFoldersManager

from box_sdk_gen.managers.web_links import WebLinksManager

from box_sdk_gen.managers.trashed_web_links import TrashedWebLinksManager

from box_sdk_gen.managers.shared_links_web_links import SharedLinksWebLinksManager

from box_sdk_gen.managers.shared_links_app_items import SharedLinksAppItemsManager

from box_sdk_gen.managers.users import UsersManager

from box_sdk_gen.managers.session_termination import SessionTerminationManager

from box_sdk_gen.managers.avatars import AvatarsManager

from box_sdk_gen.managers.transfer import TransferManager

from box_sdk_gen.managers.email_aliases import EmailAliasesManager

from box_sdk_gen.managers.memberships import MembershipsManager

from box_sdk_gen.managers.invites import InvitesManager

from box_sdk_gen.managers.groups import GroupsManager

from box_sdk_gen.managers.webhooks import WebhooksManager

from box_sdk_gen.managers.events import EventsManager

from box_sdk_gen.managers.collections import CollectionsManager

from box_sdk_gen.managers.recent_items import RecentItemsManager

from box_sdk_gen.managers.retention_policies import RetentionPoliciesManager

from box_sdk_gen.managers.retention_policy_assignments import (
    RetentionPolicyAssignmentsManager,
)

from box_sdk_gen.managers.legal_hold_policies import LegalHoldPoliciesManager

from box_sdk_gen.managers.legal_hold_policy_assignments import (
    LegalHoldPolicyAssignmentsManager,
)

from box_sdk_gen.managers.file_version_retentions import FileVersionRetentionsManager

from box_sdk_gen.managers.file_version_legal_holds import FileVersionLegalHoldsManager

from box_sdk_gen.managers.shield_information_barriers import (
    ShieldInformationBarriersManager,
)

from box_sdk_gen.managers.shield_information_barrier_reports import (
    ShieldInformationBarrierReportsManager,
)

from box_sdk_gen.managers.shield_information_barrier_segments import (
    ShieldInformationBarrierSegmentsManager,
)

from box_sdk_gen.managers.shield_information_barrier_segment_members import (
    ShieldInformationBarrierSegmentMembersManager,
)

from box_sdk_gen.managers.shield_information_barrier_segment_restrictions import (
    ShieldInformationBarrierSegmentRestrictionsManager,
)

from box_sdk_gen.managers.device_pinners import DevicePinnersManager

from box_sdk_gen.managers.terms_of_services import TermsOfServicesManager

from box_sdk_gen.managers.terms_of_service_user_statuses import (
    TermsOfServiceUserStatusesManager,
)

from box_sdk_gen.managers.collaboration_allowlist_entries import (
    CollaborationAllowlistEntriesManager,
)

from box_sdk_gen.managers.collaboration_allowlist_exempt_targets import (
    CollaborationAllowlistExemptTargetsManager,
)

from box_sdk_gen.managers.storage_policies import StoragePoliciesManager

from box_sdk_gen.managers.storage_policy_assignments import (
    StoragePolicyAssignmentsManager,
)

from box_sdk_gen.managers.zip_downloads import ZipDownloadsManager

from box_sdk_gen.managers.sign_requests import SignRequestsManager

from box_sdk_gen.managers.workflows import WorkflowsManager

from box_sdk_gen.managers.sign_templates import SignTemplatesManager

from box_sdk_gen.managers.integration_mappings import IntegrationMappingsManager

from box_sdk_gen.managers.ai import AiManager

from box_sdk_gen.managers.ai_studio import AiStudioManager

from box_sdk_gen.managers.metadata_taxonomies import MetadataTaxonomiesManager

from box_sdk_gen.managers.docgen_template import DocgenTemplateManager

from box_sdk_gen.managers.docgen import DocgenManager

from box_sdk_gen.managers.enterprise_configurations import (
    EnterpriseConfigurationsManager,
)

from box_sdk_gen.managers.hubs import HubsManager

from box_sdk_gen.managers.hub_collaborations import HubCollaborationsManager

from box_sdk_gen.managers.hub_items import HubItemsManager

from box_sdk_gen.managers.shield_lists import ShieldListsManager

from box_sdk_gen.managers.archives import ArchivesManager

from box_sdk_gen.managers.external_users import ExternalUsersManager

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.networking.base_urls import BaseUrls

from box_sdk_gen.networking.timeout_config import TimeoutConfig

from box_sdk_gen.networking.proxy_config import ProxyConfig


class BoxClient:
    def __init__(self, auth: Authentication, *, network_session: NetworkSession = None):
        if network_session is None:
            network_session = NetworkSession(base_urls=BaseUrls())
        self.auth = auth
        self.network_session = network_session
        self.authorization = AuthorizationManager(
            auth=self.auth, network_session=self.network_session
        )
        self.files = FilesManager(auth=self.auth, network_session=self.network_session)
        self.trashed_files = TrashedFilesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.app_item_associations = AppItemAssociationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.downloads = DownloadsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.uploads = UploadsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.chunked_uploads = ChunkedUploadsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.list_collaborations = ListCollaborationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.comments = CommentsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.tasks = TasksManager(auth=self.auth, network_session=self.network_session)
        self.file_versions = FileVersionsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.file_metadata = FileMetadataManager(
            auth=self.auth, network_session=self.network_session
        )
        self.file_classifications = FileClassificationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.skills = SkillsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.file_watermarks = FileWatermarksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.file_requests = FileRequestsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.folders = FoldersManager(
            auth=self.auth, network_session=self.network_session
        )
        self.trashed_folders = TrashedFoldersManager(
            auth=self.auth, network_session=self.network_session
        )
        self.folder_metadata = FolderMetadataManager(
            auth=self.auth, network_session=self.network_session
        )
        self.folder_classifications = FolderClassificationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.trashed_items = TrashedItemsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.folder_watermarks = FolderWatermarksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.folder_locks = FolderLocksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.metadata_templates = MetadataTemplatesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.classifications = ClassificationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.metadata_cascade_policies = MetadataCascadePoliciesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.search = SearchManager(
            auth=self.auth, network_session=self.network_session
        )
        self.user_collaborations = UserCollaborationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.task_assignments = TaskAssignmentsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shared_links_files = SharedLinksFilesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shared_links_folders = SharedLinksFoldersManager(
            auth=self.auth, network_session=self.network_session
        )
        self.web_links = WebLinksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.trashed_web_links = TrashedWebLinksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shared_links_web_links = SharedLinksWebLinksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shared_links_app_items = SharedLinksAppItemsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.users = UsersManager(auth=self.auth, network_session=self.network_session)
        self.session_termination = SessionTerminationManager(
            auth=self.auth, network_session=self.network_session
        )
        self.avatars = AvatarsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.transfer = TransferManager(
            auth=self.auth, network_session=self.network_session
        )
        self.email_aliases = EmailAliasesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.memberships = MembershipsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.invites = InvitesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.groups = GroupsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.webhooks = WebhooksManager(
            auth=self.auth, network_session=self.network_session
        )
        self.events = EventsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.collections = CollectionsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.recent_items = RecentItemsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.retention_policies = RetentionPoliciesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.retention_policy_assignments = RetentionPolicyAssignmentsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.legal_hold_policies = LegalHoldPoliciesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.legal_hold_policy_assignments = LegalHoldPolicyAssignmentsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.file_version_retentions = FileVersionRetentionsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.file_version_legal_holds = FileVersionLegalHoldsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shield_information_barriers = ShieldInformationBarriersManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shield_information_barrier_reports = (
            ShieldInformationBarrierReportsManager(
                auth=self.auth, network_session=self.network_session
            )
        )
        self.shield_information_barrier_segments = (
            ShieldInformationBarrierSegmentsManager(
                auth=self.auth, network_session=self.network_session
            )
        )
        self.shield_information_barrier_segment_members = (
            ShieldInformationBarrierSegmentMembersManager(
                auth=self.auth, network_session=self.network_session
            )
        )
        self.shield_information_barrier_segment_restrictions = (
            ShieldInformationBarrierSegmentRestrictionsManager(
                auth=self.auth, network_session=self.network_session
            )
        )
        self.device_pinners = DevicePinnersManager(
            auth=self.auth, network_session=self.network_session
        )
        self.terms_of_services = TermsOfServicesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.terms_of_service_user_statuses = TermsOfServiceUserStatusesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.collaboration_allowlist_entries = CollaborationAllowlistEntriesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.collaboration_allowlist_exempt_targets = (
            CollaborationAllowlistExemptTargetsManager(
                auth=self.auth, network_session=self.network_session
            )
        )
        self.storage_policies = StoragePoliciesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.storage_policy_assignments = StoragePolicyAssignmentsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.zip_downloads = ZipDownloadsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.sign_requests = SignRequestsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.workflows = WorkflowsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.sign_templates = SignTemplatesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.integration_mappings = IntegrationMappingsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.ai = AiManager(auth=self.auth, network_session=self.network_session)
        self.ai_studio = AiStudioManager(
            auth=self.auth, network_session=self.network_session
        )
        self.metadata_taxonomies = MetadataTaxonomiesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.docgen_template = DocgenTemplateManager(
            auth=self.auth, network_session=self.network_session
        )
        self.docgen = DocgenManager(
            auth=self.auth, network_session=self.network_session
        )
        self.enterprise_configurations = EnterpriseConfigurationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.hubs = HubsManager(auth=self.auth, network_session=self.network_session)
        self.hub_collaborations = HubCollaborationsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.hub_items = HubItemsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.shield_lists = ShieldListsManager(
            auth=self.auth, network_session=self.network_session
        )
        self.archives = ArchivesManager(
            auth=self.auth, network_session=self.network_session
        )
        self.external_users = ExternalUsersManager(
            auth=self.auth, network_session=self.network_session
        )

    def make_request(self, fetch_options: FetchOptions) -> FetchResponse:
        """
        Make a custom http request using the client authentication and network session.
        :param fetch_options: Options to be passed to the fetch call
        :type fetch_options: FetchOptions
        """
        auth: Authentication = (
            self.auth if fetch_options.auth == None else fetch_options.auth
        )
        network_session: NetworkSession = (
            self.network_session
            if fetch_options.network_session == None
            else fetch_options.network_session
        )
        enriched_fetch_options: FetchOptions = FetchOptions(
            auth=auth,
            network_session=network_session,
            url=fetch_options.url,
            method=fetch_options.method,
            params=fetch_options.params,
            headers=fetch_options.headers,
            data=fetch_options.data,
            file_stream=fetch_options.file_stream,
            multipart_data=fetch_options.multipart_data,
            content_type=fetch_options.content_type,
            response_format=fetch_options.response_format,
            follow_redirects=fetch_options.follow_redirects,
        )
        return network_session.network_client.fetch(enriched_fetch_options)

    def with_as_user_header(self, user_id: str) -> 'BoxClient':
        """
        Create a new client to impersonate user with the provided ID. All calls made with the new client will be made in context of the impersonated user, leaving the original client unmodified.
        :param user_id: ID of an user to impersonate
        :type user_id: str
        """
        return BoxClient(
            auth=self.auth,
            network_session=self.network_session.with_additional_headers(
                {'As-User': user_id}
            ),
        )

    def with_suppressed_notifications(self) -> 'BoxClient':
        """
        Create a new client with suppressed notifications. Calls made with the new client will not trigger email or webhook notifications
        """
        return BoxClient(
            auth=self.auth,
            network_session=self.network_session.with_additional_headers(
                {'Box-Notifications': 'off'}
            ),
        )

    def with_extra_headers(
        self, *, extra_headers: Dict[str, str] = None
    ) -> 'BoxClient':
        """
        Create a new client with a custom set of headers that will be included in every API call
        :param extra_headers: Custom set of headers that will be included in every API call, defaults to None
        :type extra_headers: Dict[str, str], optional
        """
        if extra_headers is None:
            extra_headers = {}
        return BoxClient(
            auth=self.auth,
            network_session=self.network_session.with_additional_headers(extra_headers),
        )

    def with_custom_base_urls(self, base_urls: BaseUrls) -> 'BoxClient':
        """
        Create a new client with a custom set of base urls that will be used for every API call
        :param base_urls: Custom set of base urls that will be used for every API call
        :type base_urls: BaseUrls
        """
        return BoxClient(
            auth=self.auth,
            network_session=self.network_session.with_custom_base_urls(base_urls),
        )

    def with_proxy(self, config: ProxyConfig) -> 'BoxClient':
        """
        Create a new client with a custom proxy that will be used for every API call
        """
        return BoxClient(
            auth=self.auth, network_session=self.network_session.with_proxy(config)
        )

    def with_timeouts(self, config: TimeoutConfig) -> 'BoxClient':
        """
        Create a new client with custom timeouts that will be used for every API call
        :param config: Timeout configuration.
        :type config: TimeoutConfig
        """
        return BoxClient(
            auth=self.auth,
            network_session=self.network_session.with_timeout_config(config),
        )



from typing import Optional

from box_sdk_gen.schemas.ai_llm_endpoint_params_open_ai import AiLlmEndpointParamsOpenAi

from box_sdk_gen.schemas.ai_llm_endpoint_params_google import AiLlmEndpointParamsGoogle

from box_sdk_gen.schemas.ai_llm_endpoint_params_aws import AiLlmEndpointParamsAws

from box_sdk_gen.schemas.ai_llm_endpoint_params_ibm import AiLlmEndpointParamsIbm

from box_sdk_gen.schemas.ai_llm_endpoint_params import AiLlmEndpointParams

from box_sdk_gen.schemas.ai_agent_basic_text_tool_base import AiAgentBasicTextToolBase

from box_sdk_gen.schemas.ai_agent_basic_text_tool_text_gen import (
    AiAgentBasicTextToolTextGen,
)

from box_sdk_gen.schemas.ai_agent_long_text_tool_text_gen import (
    AiAgentLongTextToolTextGenEmbeddingsField,
)

from box_sdk_gen.schemas.ai_agent_long_text_tool_text_gen import (
    AiAgentLongTextToolTextGen,
)

from box_sdk_gen.box.errors import BoxSDKError


class AiAgentBasicGenTool(AiAgentLongTextToolTextGen):
    def __init__(
        self,
        *,
        content_template: Optional[str] = None,
        embeddings: Optional[AiAgentLongTextToolTextGenEmbeddingsField] = None,
        system_message: Optional[str] = None,
        prompt_template: Optional[str] = None,
        model: Optional[str] = None,
        num_tokens_for_completion: Optional[int] = None,
        llm_endpoint_params: Optional[AiLlmEndpointParams] = None,
        **kwargs
    ):
        """
                :param content_template: How the content should be included in a request to the LLM.
        Input for `{content}` is optional, depending on the use., defaults to None
                :type content_template: Optional[str], optional
                :param system_message: System messages aim at helping the LLM understand its role and what it is supposed to do.
        The input for `{current_date}` is optional, depending on the use., defaults to None
                :type system_message: Optional[str], optional
                :param prompt_template: The prompt template contains contextual information of the request and the user prompt.

        When using the `prompt_template` parameter, you **must include** input for `{user_question}`.
        Inputs for `{current_date}` and `{content}` are optional, depending on the use., defaults to None
                :type prompt_template: Optional[str], optional
                :param model: The model used for the AI agent for basic text. For specific model values, see the [available models list](https://developer.box.com/guides/box-ai/supported-models)., defaults to None
                :type model: Optional[str], optional
                :param num_tokens_for_completion: The number of tokens for completion., defaults to None
                :type num_tokens_for_completion: Optional[int], optional
        """
        super().__init__(
            embeddings=embeddings,
            system_message=system_message,
            prompt_template=prompt_template,
            model=model,
            num_tokens_for_completion=num_tokens_for_completion,
            llm_endpoint_params=llm_endpoint_params,
            **kwargs
        )
        self.content_template = content_template



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_version_mini import FileVersionMini

from box_sdk_gen.schemas.file_mini import FileMini

from box_sdk_gen.schemas.retention_policy_mini import RetentionPolicyMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class FileVersionRetentionTypeField(str, Enum):
    FILE_VERSION_RETENTION = 'file_version_retention'


class FileVersionRetention(BaseObject):
    _discriminator = 'type', {'file_version_retention'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[FileVersionRetentionTypeField] = None,
        file_version: Optional[FileVersionMini] = None,
        file: Optional[FileMini] = None,
        applied_at: Optional[DateTime] = None,
        disposition_at: Optional[DateTime] = None,
        winning_retention_policy: Optional[RetentionPolicyMini] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this file version retention., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `file_version_retention`., defaults to None
                :type type: Optional[FileVersionRetentionTypeField], optional
                :param applied_at: When this file version retention object was
        created., defaults to None
                :type applied_at: Optional[DateTime], optional
                :param disposition_at: When the retention expires on this file
        version retention., defaults to None
                :type disposition_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.file_version = file_version
        self.file = file
        self.applied_at = applied_at
        self.disposition_at = disposition_at
        self.winning_retention_policy = winning_retention_policy



from enum import Enum

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.internal.null_value import NullValue

from typing import Union

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.retention_policies import RetentionPolicies

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.retention_policy import RetentionPolicy

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetRetentionPoliciesPolicyType(str, Enum):
    FINITE = 'finite'
    INDEFINITE = 'indefinite'


class CreateRetentionPolicyPolicyType(str, Enum):
    FINITE = 'finite'
    INDEFINITE = 'indefinite'


class CreateRetentionPolicyDispositionAction(str, Enum):
    PERMANENTLY_DELETE = 'permanently_delete'
    REMOVE_RETENTION = 'remove_retention'


class CreateRetentionPolicyRetentionType(str, Enum):
    MODIFIABLE = 'modifiable'
    NON_MODIFIABLE = 'non_modifiable'


class RetentionPoliciesManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_retention_policies(
        self,
        *,
        policy_name: Optional[str] = None,
        policy_type: Optional[GetRetentionPoliciesPolicyType] = None,
        created_by_user_id: Optional[str] = None,
        fields: Optional[List[str]] = None,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicies:
        """
                Retrieves all of the retention policies for an enterprise.
                :param policy_name: Filters results by a case sensitive prefix of the name of
        retention policies., defaults to None
                :type policy_name: Optional[str], optional
                :param policy_type: Filters results by the type of retention policy., defaults to None
                :type policy_type: Optional[GetRetentionPoliciesPolicyType], optional
                :param created_by_user_id: Filters results by the ID of the user who created policy., defaults to None
                :type created_by_user_id: Optional[str], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination., defaults to None
                :type marker: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'policy_name': to_string(policy_name),
                'policy_type': to_string(policy_type),
                'created_by_user_id': to_string(created_by_user_id),
                'fields': to_string(fields),
                'limit': to_string(limit),
                'marker': to_string(marker),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/retention_policies']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicies)

    def create_retention_policy(
        self,
        policy_name: str,
        policy_type: CreateRetentionPolicyPolicyType,
        disposition_action: CreateRetentionPolicyDispositionAction,
        *,
        description: Optional[str] = None,
        retention_length: Optional[str] = None,
        retention_type: Optional[CreateRetentionPolicyRetentionType] = None,
        can_owner_extend_retention: Optional[bool] = None,
        are_owners_notified: Optional[bool] = None,
        custom_notification_recipients: Optional[List[UserMini]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicy:
        """
                Creates a retention policy.
                :param policy_name: The name for the retention policy.
                :type policy_name: str
                :param policy_type: The type of the retention policy. A retention
        policy type can either be `finite`, where a
        specific amount of time to retain the content is known
        upfront, or `indefinite`, where the amount of time
        to retain the content is still unknown.
                :type policy_type: CreateRetentionPolicyPolicyType
                :param disposition_action: The disposition action of the retention policy.
        `permanently_delete` deletes the content
        retained by the policy permanently.
        `remove_retention` lifts retention policy
        from the content, allowing it to be deleted
        by users once the retention policy has expired.
                :type disposition_action: CreateRetentionPolicyDispositionAction
                :param description: The additional text description of the retention policy., defaults to None
                :type description: Optional[str], optional
                :param retention_length: The length of the retention policy. This value
        specifies the duration in days that the retention
        policy will be active for after being assigned to
        content.  If the policy has a `policy_type` of
        `indefinite`, the `retention_length` will also be
        `indefinite`., defaults to None
                :type retention_length: Optional[str], optional
                :param retention_type: Specifies the retention type:

        * `modifiable`: You can modify the retention policy. For example,
        you can add or remove folders, shorten or lengthen
        the policy duration, or delete the assignment.
        Use this type if your retention policy
        is not related to any regulatory purposes.

        * `non_modifiable`: You can modify the retention policy
        only in a limited way: add a folder, lengthen the duration,
        retire the policy, change the disposition action
        or notification settings. You cannot perform other actions,
        such as deleting the assignment or shortening the
        policy duration. Use this type to ensure
        compliance with regulatory retention policies., defaults to None
                :type retention_type: Optional[CreateRetentionPolicyRetentionType], optional
                :param can_owner_extend_retention: Whether the owner of a file will be allowed to
        extend the retention., defaults to None
                :type can_owner_extend_retention: Optional[bool], optional
                :param are_owners_notified: Whether owner and co-owners of a file are notified
        when the policy nears expiration., defaults to None
                :type are_owners_notified: Optional[bool], optional
                :param custom_notification_recipients: A list of users notified when
        the retention policy duration is about to end., defaults to None
                :type custom_notification_recipients: Optional[List[UserMini]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'policy_name': policy_name,
            'description': description,
            'policy_type': policy_type,
            'disposition_action': disposition_action,
            'retention_length': retention_length,
            'retention_type': retention_type,
            'can_owner_extend_retention': can_owner_extend_retention,
            'are_owners_notified': are_owners_notified,
            'custom_notification_recipients': custom_notification_recipients,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/retention_policies']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicy)

    def get_retention_policy_by_id(
        self,
        retention_policy_id: str,
        *,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicy:
        """
                Retrieves a retention policy.
                :param retention_policy_id: The ID of the retention policy.
        Example: "982312"
                :type retention_policy_id: str
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'fields': to_string(fields)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policies/',
                        to_string(retention_policy_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicy)

    def update_retention_policy_by_id(
        self,
        retention_policy_id: str,
        *,
        policy_name: Union[Optional[str], NullValue] = None,
        description: Union[Optional[str], NullValue] = None,
        disposition_action: Optional[str] = None,
        retention_type: Union[Optional[str], NullValue] = None,
        retention_length: Optional[str] = None,
        status: Union[Optional[str], NullValue] = None,
        can_owner_extend_retention: Union[Optional[bool], NullValue] = None,
        are_owners_notified: Union[Optional[bool], NullValue] = None,
        custom_notification_recipients: Union[
            Optional[List[UserBase]], NullValue
        ] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> RetentionPolicy:
        """
                Updates a retention policy.
                :param retention_policy_id: The ID of the retention policy.
        Example: "982312"
                :type retention_policy_id: str
                :param policy_name: The name for the retention policy., defaults to None
                :type policy_name: Union[Optional[str], NullValue], optional
                :param description: The additional text description of the retention policy., defaults to None
                :type description: Union[Optional[str], NullValue], optional
                :param disposition_action: The disposition action of the retention policy.
        This action can be `permanently_delete`, which
        will cause the content retained by the policy
        to be permanently deleted, or `remove_retention`,
        which will lift the retention policy from the content,
        allowing it to be deleted by users,
        once the retention policy has expired.
        You can use `null` if you don't want to change `disposition_action`., defaults to None
                :type disposition_action: Optional[str], optional
                :param retention_type: Specifies the retention type:

        * `modifiable`: You can modify the retention policy. For example,
        you can add or remove folders, shorten or lengthen
        the policy duration, or delete the assignment.
        Use this type if your retention policy
        is not related to any regulatory purposes.
        * `non-modifiable`: You can modify the retention policy
        only in a limited way: add a folder, lengthen the duration,
        retire the policy, change the disposition action
        or notification settings. You cannot perform other actions,
        such as deleting the assignment or shortening the
        policy duration. Use this type to ensure
        compliance with regulatory retention policies.

        When updating a retention policy, you can use
        `non-modifiable` type only. You can convert a
        `modifiable` policy to `non-modifiable`, but
        not the other way around., defaults to None
                :type retention_type: Union[Optional[str], NullValue], optional
                :param retention_length: The length of the retention policy. This value
        specifies the duration in days that the retention
        policy will be active for after being assigned to
        content.  If the policy has a `policy_type` of
        `indefinite`, the `retention_length` will also be
        `indefinite`., defaults to None
                :type retention_length: Optional[str], optional
                :param status: Used to retire a retention policy.

        If not retiring a policy, do not include this parameter
        or set it to `null`., defaults to None
                :type status: Union[Optional[str], NullValue], optional
                :param can_owner_extend_retention: Determines if the owner of items under the policy
        can extend the retention when the original retention
        duration is about to end., defaults to None
                :type can_owner_extend_retention: Union[Optional[bool], NullValue], optional
                :param are_owners_notified: Determines if owners and co-owners of items
        under the policy are notified when
        the retention duration is about to end., defaults to None
                :type are_owners_notified: Union[Optional[bool], NullValue], optional
                :param custom_notification_recipients: A list of users notified when the retention duration is about to end., defaults to None
                :type custom_notification_recipients: Union[Optional[List[UserBase]], NullValue], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'policy_name': policy_name,
            'description': description,
            'disposition_action': disposition_action,
            'retention_type': retention_type,
            'retention_length': retention_length,
            'status': status,
            'can_owner_extend_retention': can_owner_extend_retention,
            'are_owners_notified': are_owners_notified,
            'custom_notification_recipients': custom_notification_recipients,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policies/',
                        to_string(retention_policy_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, RetentionPolicy)

    def delete_retention_policy_by_id(
        self,
        retention_policy_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Permanently deletes a retention policy.
                :param retention_policy_id: The ID of the retention policy.
        Example: "982312"
                :type retention_policy_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/retention_policies/',
                        to_string(retention_policy_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from abc import abstractmethod

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse


class NetworkClient:
    def __init__(self):
        pass

    @abstractmethod
    def fetch(self, options: FetchOptions) -> FetchResponse:
        pass



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.zip_download import ZipDownload

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.zip_download_request import ZipDownloadRequest

from box_sdk_gen.schemas.zip_download_status import ZipDownloadStatus

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.serialization.json import sd_to_json


class CreateZipDownloadItemsTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class CreateZipDownloadItems(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(self, type: CreateZipDownloadItemsTypeField, id: str, **kwargs):
        """
                :param type: The type of the item to add to the archive.
                :type type: CreateZipDownloadItemsTypeField
                :param id: The identifier of the item to add to the archive. When this item is
        a folder then this can not be the root folder with ID `0`.
                :type id: str
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class DownloadZipItemsTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class DownloadZipItems(BaseObject):
    _discriminator = 'type', {'file', 'folder'}

    def __init__(self, type: DownloadZipItemsTypeField, id: str, **kwargs):
        """
                :param type: The type of the item to add to the archive.
                :type type: DownloadZipItemsTypeField
                :param id: The identifier of the item to add to the archive. When this item is
        a folder then this can not be the root folder with ID `0`.
                :type id: str
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class ZipDownloadsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def create_zip_download(
        self,
        items: List[CreateZipDownloadItems],
        *,
        download_file_name: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ZipDownload:
        """
                Creates a request to download multiple files and folders as a single `zip`

                archive file. This API does not return the archive but instead performs all


                the checks to ensure that the user has access to all the items, and then


                returns a `download_url` and a `status_url` that can be used to download the


                archive.


                The limit for an archive is either the Account's upload limit or


                10,000 files, whichever is met first.


                **Note**: Downloading a large file can be


                affected by various


                factors such as distance, network latency,


                bandwidth, and congestion, as well as packet loss


                ratio and current server load.


                For these reasons we recommend that a maximum ZIP archive


                total size does not exceed 25GB.

                :param items: A list of items to add to the `zip` archive. These can
        be folders or files.
                :type items: List[CreateZipDownloadItems]
                :param download_file_name: The optional name of the `zip` archive. This name will be appended by the
        `.zip` file extension, for example `January Financials.zip`., defaults to None
                :type download_file_name: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'items': items, 'download_file_name': download_file_name}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/zip_downloads']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ZipDownload)

    def get_zip_download_content(
        self,
        download_url: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ByteStream:
        """
               Returns the contents of a `zip` archive in binary format. This URL does not

               require any form of authentication and could be used in a user's browser to


               download the archive to a user's device.


               By default, this URL is only valid for a few seconds from the creation of


               the request for this archive. Once a download has started it can not be


               stopped and resumed, instead a new request for a zip archive would need to


               be created.


               The URL of this endpoint should not be considered as fixed. Instead, use


               the [Create zip download](https://developer.box.com/reference/post-zip-downloads) API to request to create a


               `zip` archive, and then follow the `download_url` field in the response to


               this endpoint.

               :param download_url: The URL that can be used to download created `zip` archive.
        Example: `https://dl.boxcloud.com/2.0/zip_downloads/29l00nfxDyHOt7RphI9zT_w==nDnZEDjY2S8iEWWCHEEiptFxwoWojjlibZjJ6geuE5xnXENDTPxzgbks_yY=/content`
               :type download_url: str
               :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
               :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=download_url,
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.BINARY,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return response.content

    def get_zip_download_status(
        self,
        status_url: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ZipDownloadStatus:
        """
               Returns the download status of a `zip` archive, allowing an application to

               inspect the progress of the download as well as the number of items that


               might have been skipped.


               This endpoint can only be accessed once the download has started.


               Subsequently this endpoint is valid for 12 hours from the start of the


               download.


               The URL of this endpoint should not be considered as fixed. Instead, use


               the [Create zip download](https://developer.box.com/reference/post-zip-downloads) API to request to create a


               `zip` archive, and then follow the `status_url` field in the response to


               this endpoint.

               :param status_url: The URL that can be used to get the status of the `zip` archive being downloaded.
        Example: `https://dl.boxcloud.com/2.0/zip_downloads/29l00nfxDyHOt7RphI9zT_w==nDnZEDjY2S8iEWWCHEEiptFxwoWojjlibZjJ6geuE5xnXENDTPxzgbks_yY=/status`
               :type status_url: str
               :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
               :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=status_url,
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ZipDownloadStatus)

    def download_zip(
        self,
        items: List[DownloadZipItems],
        *,
        download_file_name: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ByteStream:
        """
                Creates a zip and downloads its content
                :param items: A list of items to add to the `zip` archive. These can
        be folders or files.
                :type items: List[DownloadZipItems]
                :param download_file_name: The optional name of the `zip` archive. This name will be appended by the
        `.zip` file extension, for example `January Financials.zip`., defaults to None
                :type download_file_name: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'items': items, 'download_file_name': download_file_name}
        zip_download_session: ZipDownload = self.create_zip_download(
            items, download_file_name=download_file_name, extra_headers=extra_headers
        )
        return self.get_zip_download_content(
            zip_download_session.download_url, extra_headers=extra_headers
        )



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class RealtimeServer(BaseObject):
    def __init__(
        self,
        *,
        type: Optional[str] = None,
        url: Optional[str] = None,
        ttl: Optional[str] = None,
        max_retries: Optional[str] = None,
        retry_timeout: Optional[int] = None,
        **kwargs
    ):
        """
                :param type: The value will always be `realtime_server`., defaults to None
                :type type: Optional[str], optional
                :param url: The URL for the server., defaults to None
                :type url: Optional[str], optional
                :param ttl: The time in minutes for which this server is available., defaults to None
                :type ttl: Optional[str], optional
                :param max_retries: The maximum number of retries this server will
        allow before a new long poll should be started by
        getting a [new list of server](https://developer.box.com/reference/options-events)., defaults to None
                :type max_retries: Optional[str], optional
                :param retry_timeout: The maximum number of seconds without a response
        after which you should retry the long poll connection.

        This helps to overcome network issues where the long
        poll looks to be working but no packages are coming
        through., defaults to None
                :type retry_timeout: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.url = url
        self.ttl = ttl
        self.max_retries = max_retries
        self.retry_timeout = retry_timeout



from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.internal.utils import write_input_stream_to_output_stream

from box_sdk_gen.internal.utils import OutputStream


class DownloadsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_download_file_url(
        self,
        file_id: str,
        *,
        version: Optional[str] = None,
        access_token: Optional[str] = None,
        range: Optional[str] = None,
        boxapi: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> str:
        """
                Returns the contents of a file in binary format.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param version: The file version to download., defaults to None
                :type version: Optional[str], optional
                :param access_token: An optional access token that can be used to pre-authenticate this request, which means that a download link can be shared with a browser or a third party service without them needing to know how to handle the authentication.
        When using this parameter, please make sure that the access token is sufficiently scoped down to only allow read access to that file and no other files or folders., defaults to None
                :type access_token: Optional[str], optional
                :param range: The byte range of the content to download.

        The format `bytes={start_byte}-{end_byte}` can be used to specify
        what section of the file to download., defaults to None
                :type range: Optional[str], optional
                :param boxapi: The URL, and optional password, for the shared link of this item.

        This header can be used to access items that have not been
        explicitly shared with a user.

        Use the format `shared_link=[link]` or if a password is required then
        use `shared_link=[link]&shared_link_password=[password]`.

        This header can be used on the file or folder shared, as well as on any files
        or folders nested within the item., defaults to None
                :type boxapi: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'version': to_string(version), 'access_token': to_string(access_token)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'range': to_string(range), 'boxapi': to_string(boxapi), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/content',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
                follow_redirects=False,
            )
        )
        if 'location' in response.headers:
            return response.headers.get('location')
        if 'Location' in response.headers:
            return response.headers.get('Location')
        raise BoxSDKError(message='No location header in response')

    def download_file(
        self,
        file_id: str,
        *,
        version: Optional[str] = None,
        access_token: Optional[str] = None,
        range: Optional[str] = None,
        boxapi: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Optional[ByteStream]:
        """
                Returns the contents of a file in binary format.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param version: The file version to download., defaults to None
                :type version: Optional[str], optional
                :param access_token: An optional access token that can be used to pre-authenticate this request, which means that a download link can be shared with a browser or a third party service without them needing to know how to handle the authentication.
        When using this parameter, please make sure that the access token is sufficiently scoped down to only allow read access to that file and no other files or folders., defaults to None
                :type access_token: Optional[str], optional
                :param range: The byte range of the content to download.

        The format `bytes={start_byte}-{end_byte}` can be used to specify
        what section of the file to download., defaults to None
                :type range: Optional[str], optional
                :param boxapi: The URL, and optional password, for the shared link of this item.

        This header can be used to access items that have not been
        explicitly shared with a user.

        Use the format `shared_link=[link]` or if a password is required then
        use `shared_link=[link]&shared_link_password=[password]`.

        This header can be used on the file or folder shared, as well as on any files
        or folders nested within the item., defaults to None
                :type boxapi: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'version': to_string(version), 'access_token': to_string(access_token)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'range': to_string(range), 'boxapi': to_string(boxapi), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/content',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.BINARY,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        if to_string(response.status) == '202':
            return None
        return response.content

    def download_file_to_output_stream(
        self,
        file_id: str,
        output_stream: OutputStream,
        *,
        version: Optional[str] = None,
        access_token: Optional[str] = None,
        range: Optional[str] = None,
        boxapi: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param output_stream: Download file to a given output stream
                :type output_stream: OutputStream
                :param version: The file version to download., defaults to None
                :type version: Optional[str], optional
                :param access_token: An optional access token that can be used to pre-authenticate this request, which means that a download link can be shared with a browser or a third party service without them needing to know how to handle the authentication.
        When using this parameter, please make sure that the access token is sufficiently scoped down to only allow read access to that file and no other files or folders., defaults to None
                :type access_token: Optional[str], optional
                :param range: The byte range of the content to download.

        The format `bytes={start_byte}-{end_byte}` can be used to specify
        what section of the file to download., defaults to None
                :type range: Optional[str], optional
                :param boxapi: The URL, and optional password, for the shared link of this item.

        This header can be used to access items that have not been
        explicitly shared with a user.

        Use the format `shared_link=[link]` or if a password is required then
        use `shared_link=[link]&shared_link_password=[password]`.

        This header can be used on the file or folder shared, as well as on any files
        or folders nested within the item., defaults to None
                :type boxapi: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        download_stream: ByteStream = self.download_file(
            file_id,
            version=version,
            access_token=access_token,
            range=range,
            boxapi=boxapi,
            extra_headers=extra_headers,
        )
        write_input_stream_to_output_stream(download_stream, output_stream)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class InviteTypeField(str, Enum):
    INVITE = 'invite'


class InviteInvitedToTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class InviteInvitedToField(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[InviteInvitedToTypeField] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[InviteInvitedToTypeField], optional
        :param name: The name of the enterprise., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name


class Invite(BaseObject):
    _discriminator = 'type', {'invite'}

    def __init__(
        self,
        id: str,
        *,
        type: InviteTypeField = InviteTypeField.INVITE,
        invited_to: Optional[InviteInvitedToField] = None,
        actionable_by: Optional[UserMini] = None,
        invited_by: Optional[UserMini] = None,
        status: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this invite.
        :type id: str
        :param type: The value will always be `invite`., defaults to InviteTypeField.INVITE
        :type type: InviteTypeField, optional
        :param invited_to: A representation of a Box enterprise., defaults to None
        :type invited_to: Optional[InviteInvitedToField], optional
        :param status: The status of the invite., defaults to None
        :type status: Optional[str], optional
        :param created_at: When the invite was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: When the invite was modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.invited_to = invited_to
        self.actionable_by = actionable_by
        self.invited_by = invited_by
        self.status = status
        self.created_at = created_at
        self.modified_at = modified_at



from typing import Optional

from box_sdk_gen.schemas.file_version_base import FileVersionBaseTypeField

from box_sdk_gen.schemas.file_version_base import FileVersionBase

from box_sdk_gen.schemas.file_version_mini import FileVersionMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class FileVersion(FileVersionMini):
    def __init__(
        self,
        id: str,
        *,
        name: Optional[str] = None,
        size: Optional[int] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        modified_by: Optional[UserMini] = None,
        trashed_at: Optional[DateTime] = None,
        trashed_by: Optional[UserMini] = None,
        restored_at: Optional[DateTime] = None,
        restored_by: Optional[UserMini] = None,
        purged_at: Optional[DateTime] = None,
        uploader_display_name: Optional[str] = None,
        sha_1: Optional[str] = None,
        type: FileVersionBaseTypeField = FileVersionBaseTypeField.FILE_VERSION,
        **kwargs
    ):
        """
        :param id: The unique identifier that represent a file version.
        :type id: str
        :param name: The name of the file version., defaults to None
        :type name: Optional[str], optional
        :param size: Size of the file version in bytes., defaults to None
        :type size: Optional[int], optional
        :param created_at: When the file version object was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: When the file version object was last updated., defaults to None
        :type modified_at: Optional[DateTime], optional
        :param trashed_at: When the file version object was trashed., defaults to None
        :type trashed_at: Optional[DateTime], optional
        :param restored_at: When the file version was restored from the trash., defaults to None
        :type restored_at: Optional[DateTime], optional
        :param purged_at: When the file version object will be permanently deleted., defaults to None
        :type purged_at: Optional[DateTime], optional
        :param sha_1: The SHA1 hash of this version of the file., defaults to None
        :type sha_1: Optional[str], optional
        :param type: The value will always be `file_version`., defaults to FileVersionBaseTypeField.FILE_VERSION
        :type type: FileVersionBaseTypeField, optional
        """
        super().__init__(id=id, sha_1=sha_1, type=type, **kwargs)
        self.name = name
        self.size = size
        self.created_at = created_at
        self.modified_at = modified_at
        self.modified_by = modified_by
        self.trashed_at = trashed_at
        self.trashed_by = trashed_by
        self.restored_at = restored_at
        self.restored_by = restored_by
        self.purged_at = purged_at
        self.uploader_display_name = uploader_display_name



from enum import Enum

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListContentCountryV2025R0TypeField(str, Enum):
    COUNTRY = 'country'


class ShieldListContentCountryV2025R0(BaseObject):
    _discriminator = 'type', {'country'}

    def __init__(
        self,
        country_codes: List[str],
        *,
        type: ShieldListContentCountryV2025R0TypeField = ShieldListContentCountryV2025R0TypeField.COUNTRY,
        **kwargs
    ):
        """
        :param country_codes: List of country codes values.
        :type country_codes: List[str]
        :param type: The type of content in the shield list., defaults to ShieldListContentCountryV2025R0TypeField.COUNTRY
        :type type: ShieldListContentCountryV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.country_codes = country_codes
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListMiniV2025R0TypeField(str, Enum):
    SHIELD_LIST = 'shield_list'


class ShieldListMiniV2025R0ContentField(BaseObject):
    def __init__(self, *, type: Optional[str] = None, **kwargs):
        """
        :param type: The type of content in the shield list., defaults to None
        :type type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type


class ShieldListMiniV2025R0(BaseObject):
    _discriminator = 'type', {'shield_list'}

    def __init__(
        self,
        id: str,
        name: str,
        content: ShieldListMiniV2025R0ContentField,
        *,
        type: ShieldListMiniV2025R0TypeField = ShieldListMiniV2025R0TypeField.SHIELD_LIST,
        **kwargs
    ):
        """
        :param id: Unique global identifier for this list.
        :type id: str
        :param name: Name of Shield List.
        :type name: str
        :param type: The type of object., defaults to ShieldListMiniV2025R0TypeField.SHIELD_LIST
        :type type: ShieldListMiniV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.name = name
        self.content = content
        self.type = type



from typing import Optional

from box_sdk_gen.schemas.metadata_base import MetadataBase

from box_sdk_gen.box.errors import BoxSDKError


class Metadata(MetadataBase):
    def __init__(
        self,
        *,
        parent: Optional[str] = None,
        template: Optional[str] = None,
        scope: Optional[str] = None,
        version: Optional[int] = None,
        **kwargs
    ):
        """
                :param parent: The identifier of the item that this metadata instance
        has been attached to. This combines the `type` and the `id`
        of the parent in the form `{type}_{id}`., defaults to None
                :type parent: Optional[str], optional
                :param template: The name of the template., defaults to None
                :type template: Optional[str], optional
                :param scope: An ID for the scope in which this template
        has been applied. This will be `enterprise_{enterprise_id}` for templates
        defined for use in this enterprise, and `global` for general templates
        that are available to all enterprises using Box., defaults to None
                :type scope: Optional[str], optional
                :param version: The version of the metadata instance. This version starts at 0 and
        increases every time a user-defined property is modified., defaults to None
                :type version: Optional[int], optional
        """
        super().__init__(
            parent=parent, template=template, scope=scope, version=version, **kwargs
        )



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class EmailAliasTypeField(str, Enum):
    EMAIL_ALIAS = 'email_alias'


class EmailAlias(BaseObject):
    _discriminator = 'type', {'email_alias'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[EmailAliasTypeField] = None,
        email: Optional[str] = None,
        is_confirmed: Optional[bool] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this object., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `email_alias`., defaults to None
        :type type: Optional[EmailAliasTypeField], optional
        :param email: The email address., defaults to None
        :type email: Optional[str], optional
        :param is_confirmed: Whether the email address has been confirmed., defaults to None
        :type is_confirmed: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.email = email
        self.is_confirmed = is_confirmed



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.legal_hold_policy_assignments import LegalHoldPolicyAssignments

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.legal_hold_policy_assignment import LegalHoldPolicyAssignment

from box_sdk_gen.schemas.files_on_hold import FilesOnHold

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetLegalHoldPolicyAssignmentsAssignToType(str, Enum):
    FILE = 'file'
    FILE_VERSION = 'file_version'
    FOLDER = 'folder'
    USER = 'user'
    OWNERSHIP = 'ownership'
    INTERACTIONS = 'interactions'


class CreateLegalHoldPolicyAssignmentAssignToTypeField(str, Enum):
    FILE = 'file'
    FILE_VERSION = 'file_version'
    FOLDER = 'folder'
    USER = 'user'
    OWNERSHIP = 'ownership'
    INTERACTIONS = 'interactions'


class CreateLegalHoldPolicyAssignmentAssignTo(BaseObject):
    _discriminator = 'type', {
        'file',
        'file_version',
        'folder',
        'user',
        'ownership',
        'interactions',
    }

    def __init__(
        self, type: CreateLegalHoldPolicyAssignmentAssignToTypeField, id: str, **kwargs
    ):
        """
        :param type: The type of item to assign the policy to.
        :type type: CreateLegalHoldPolicyAssignmentAssignToTypeField
        :param id: The ID of item to assign the policy to.
        :type id: str
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class LegalHoldPolicyAssignmentsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_legal_hold_policy_assignments(
        self,
        policy_id: str,
        *,
        assign_to_type: Optional[GetLegalHoldPolicyAssignmentsAssignToType] = None,
        assign_to_id: Optional[str] = None,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> LegalHoldPolicyAssignments:
        """
                Retrieves a list of items a legal hold policy has been assigned to.
                :param policy_id: The ID of the legal hold policy.
                :type policy_id: str
                :param assign_to_type: Filters the results by the type of item the
        policy was applied to., defaults to None
                :type assign_to_type: Optional[GetLegalHoldPolicyAssignmentsAssignToType], optional
                :param assign_to_id: Filters the results by the ID of item the
        policy was applied to., defaults to None
                :type assign_to_id: Optional[str], optional
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'policy_id': to_string(policy_id),
                'assign_to_type': to_string(assign_to_type),
                'assign_to_id': to_string(assign_to_id),
                'marker': to_string(marker),
                'limit': to_string(limit),
                'fields': to_string(fields),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/legal_hold_policy_assignments',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, LegalHoldPolicyAssignments)

    def create_legal_hold_policy_assignment(
        self,
        policy_id: str,
        assign_to: CreateLegalHoldPolicyAssignmentAssignTo,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> LegalHoldPolicyAssignment:
        """
        Assign a legal hold to an item type of: file, file version, folder, user, ownership, or interactions.
        :param policy_id: The ID of the policy to assign.
        :type policy_id: str
        :param assign_to: The item to assign the policy to.
        :type assign_to: CreateLegalHoldPolicyAssignmentAssignTo
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'policy_id': policy_id, 'assign_to': assign_to}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/legal_hold_policy_assignments',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, LegalHoldPolicyAssignment)

    def get_legal_hold_policy_assignment_by_id(
        self,
        legal_hold_policy_assignment_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> LegalHoldPolicyAssignment:
        """
                Retrieve a legal hold policy assignment.
                :param legal_hold_policy_assignment_id: The ID of the legal hold policy assignment.
        Example: "753465"
                :type legal_hold_policy_assignment_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/legal_hold_policy_assignments/',
                        to_string(legal_hold_policy_assignment_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, LegalHoldPolicyAssignment)

    def delete_legal_hold_policy_assignment_by_id(
        self,
        legal_hold_policy_assignment_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Remove a legal hold from an item.

                This is an asynchronous process. The policy will not be


                fully removed yet when the response returns.

                :param legal_hold_policy_assignment_id: The ID of the legal hold policy assignment.
        Example: "753465"
                :type legal_hold_policy_assignment_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/legal_hold_policy_assignments/',
                        to_string(legal_hold_policy_assignment_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def get_legal_hold_policy_assignment_file_on_hold(
        self,
        legal_hold_policy_assignment_id: str,
        *,
        marker: Optional[str] = None,
        limit: Optional[int] = None,
        fields: Optional[List[str]] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FilesOnHold:
        """
                Get a list of files with current file versions for a legal hold

                assignment.


                In some cases you may want to get previous file versions instead. In these


                cases, use the `GET  /legal_hold_policy_assignments/:id/file_versions_on_hold`


                API instead to return any previous versions of a file for this legal hold


                policy assignment.


                Due to ongoing re-architecture efforts this API might not return all file


                versions held for this policy ID. Instead, this API will only return the


                latest file version held in the newly developed architecture. The `GET


                /file_version_legal_holds` API can be used to fetch current and past versions


                of files held within the legacy architecture.


                This endpoint does not support returning any content that is on hold due to


                a Custodian collaborating on a Hub.


                The `GET /legal_hold_policy_assignments?policy_id={id}` API can be used to


                find a list of policy assignments for a given policy ID.

                :param legal_hold_policy_assignment_id: The ID of the legal hold policy assignment.
        Example: "753465"
                :type legal_hold_policy_assignment_id: str
                :param marker: Defines the position marker at which to begin returning results. This is
        used when paginating using marker-based pagination.

        This requires `usemarker` to be set to `true`., defaults to None
                :type marker: Optional[str], optional
                :param limit: The maximum number of items to return per page., defaults to None
                :type limit: Optional[int], optional
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {
                'marker': to_string(marker),
                'limit': to_string(limit),
                'fields': to_string(fields),
            }
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/legal_hold_policy_assignments/',
                        to_string(legal_hold_policy_assignment_id),
                        '/files_on_hold',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FilesOnHold)



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.file_full import FileFull

from box_sdk_gen.schemas.folder_full import FolderFull

from box_sdk_gen.schemas.metadata_query_result_item import MetadataQueryResultItem

from box_sdk_gen.box.errors import BoxSDKError


class MetadataQueryResults(BaseObject):
    def __init__(
        self,
        *,
        entries: Optional[List[MetadataQueryResultItem]] = None,
        limit: Optional[int] = None,
        next_marker: Optional[str] = None,
        **kwargs
    ):
        """
                :param entries: The mini representation of the files and folders that match the search
        terms.

        By default, this endpoint returns only the most basic info about the
        items. To get additional fields for each item, including any of the
        metadata, use the `fields` attribute in the query., defaults to None
                :type entries: Optional[List[MetadataQueryResultItem]], optional
                :param limit: The limit that was used for this search. This will be the same as the
        `limit` query parameter unless that value exceeded the maximum value
        allowed., defaults to None
                :type limit: Optional[int], optional
                :param next_marker: The marker for the start of the next page of results., defaults to None
                :type next_marker: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.entries = entries
        self.limit = limit
        self.next_marker = next_marker



from typing import Optional

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_item_v2025_r0 import (
    EnterpriseConfigurationItemV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class EnterpriseConfigurationItemStringV2025R0(EnterpriseConfigurationItemV2025R0):
    def __init__(
        self, *, value: Optional[str] = None, is_used: Optional[bool] = None, **kwargs
    ):
        """
        :param value: The value of the enterprise configuration as a string., defaults to None
        :type value: Optional[str], optional
        :param is_used: Indicates whether a configuration is used for a given enterprise., defaults to None
        :type is_used: Optional[bool], optional
        """
        super().__init__(is_used=is_used, **kwargs)
        self.value = value



from typing import Union

from box_sdk_gen.schemas.ai_agent_reference import AiAgentReference

from box_sdk_gen.schemas.ai_agent_ask import AiAgentAsk

from box_sdk_gen.box.errors import BoxSDKError

AiAskAgent = Union[AiAgentReference, AiAgentAsk]



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.folder_base import FolderBaseTypeField

from box_sdk_gen.schemas.folder_base import FolderBase

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.folder import FolderPathCollectionField

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.schemas.folder import FolderSharedLinkField

from box_sdk_gen.schemas.folder import FolderFolderUploadEmailField

from box_sdk_gen.schemas.folder import FolderItemStatusField

from box_sdk_gen.schemas.items import Items

from box_sdk_gen.schemas.folder import Folder

from box_sdk_gen.schemas.metadata_full import MetadataFull

from box_sdk_gen.box.errors import BoxSDKError


class FolderFullSyncStateField(str, Enum):
    SYNCED = 'synced'
    NOT_SYNCED = 'not_synced'
    PARTIALLY_SYNCED = 'partially_synced'


class FolderFullPermissionsField(BaseObject):
    def __init__(
        self,
        can_delete: bool,
        can_download: bool,
        can_invite_collaborator: bool,
        can_rename: bool,
        can_set_share_access: bool,
        can_share: bool,
        can_upload: bool,
        *,
        can_apply_watermark: Optional[bool] = None,
        **kwargs
    ):
        """
                :param can_delete: Specifies if the current user can delete this item.
                :type can_delete: bool
                :param can_download: Specifies if the current user can download this item.
                :type can_download: bool
                :param can_invite_collaborator: Specifies if the current user can invite new
        users to collaborate on this item, and if the user can
        update the role of a user already collaborated on this
        item.
                :type can_invite_collaborator: bool
                :param can_rename: Specifies if the user can rename this item.
                :type can_rename: bool
                :param can_set_share_access: Specifies if the user can change the access level of an
        existing shared link on this item.
                :type can_set_share_access: bool
                :param can_share: Specifies if the user can create a shared link for this item.
                :type can_share: bool
                :param can_upload: Specifies if the user can upload into this folder.
                :type can_upload: bool
                :param can_apply_watermark: Specifies if the user can apply a watermark to this folder and its contents., defaults to None
                :type can_apply_watermark: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.can_delete = can_delete
        self.can_download = can_download
        self.can_invite_collaborator = can_invite_collaborator
        self.can_rename = can_rename
        self.can_set_share_access = can_set_share_access
        self.can_share = can_share
        self.can_upload = can_upload
        self.can_apply_watermark = can_apply_watermark


class FolderFullMetadataField(BaseObject):
    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self.extra_data = kwargs


class FolderFullAllowedSharedLinkAccessLevelsField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class FolderFullAllowedInviteeRolesField(str, Enum):
    EDITOR = 'editor'
    VIEWER = 'viewer'
    PREVIEWER = 'previewer'
    UPLOADER = 'uploader'
    PREVIEWER_UPLOADER = 'previewer uploader'
    VIEWER_UPLOADER = 'viewer uploader'
    CO_OWNER = 'co-owner'


class FolderFullWatermarkInfoField(BaseObject):
    def __init__(
        self,
        *,
        is_watermarked: Optional[bool] = None,
        is_watermark_inherited: Optional[bool] = None,
        is_watermarked_by_access_policy: Optional[bool] = None,
        **kwargs
    ):
        """
        :param is_watermarked: Specifies if this item has a watermark applied., defaults to None
        :type is_watermarked: Optional[bool], optional
        :param is_watermark_inherited: Specifies if the watermark is inherited from any parent folder in the hierarchy., defaults to None
        :type is_watermark_inherited: Optional[bool], optional
        :param is_watermarked_by_access_policy: Specifies if the watermark is enforced by an access policy., defaults to None
        :type is_watermarked_by_access_policy: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.is_watermarked = is_watermarked
        self.is_watermark_inherited = is_watermark_inherited
        self.is_watermarked_by_access_policy = is_watermarked_by_access_policy


class FolderFullClassificationField(BaseObject):
    def __init__(
        self,
        *,
        name: Optional[str] = None,
        definition: Optional[str] = None,
        color: Optional[str] = None,
        **kwargs
    ):
        """
                :param name: The name of the classification., defaults to None
                :type name: Optional[str], optional
                :param definition: An explanation of the meaning of this classification., defaults to None
                :type definition: Optional[str], optional
                :param color: The color that is used to display the
        classification label in a user-interface. Colors are defined by the admin
        or co-admin who created the classification in the Box web app., defaults to None
                :type color: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.name = name
        self.definition = definition
        self.color = color


class FolderFull(Folder):
    def __init__(
        self,
        id: str,
        *,
        sync_state: Optional[FolderFullSyncStateField] = None,
        has_collaborations: Optional[bool] = None,
        permissions: Optional[FolderFullPermissionsField] = None,
        tags: Optional[List[str]] = None,
        can_non_owners_invite: Optional[bool] = None,
        is_externally_owned: Optional[bool] = None,
        metadata: Optional[FolderFullMetadataField] = None,
        is_collaboration_restricted_to_enterprise: Optional[bool] = None,
        allowed_shared_link_access_levels: Optional[
            List[FolderFullAllowedSharedLinkAccessLevelsField]
        ] = None,
        allowed_invitee_roles: Optional[
            List[FolderFullAllowedInviteeRolesField]
        ] = None,
        watermark_info: Optional[FolderFullWatermarkInfoField] = None,
        is_accessible_via_shared_link: Optional[bool] = None,
        can_non_owners_view_collaborators: Optional[bool] = None,
        classification: Optional[FolderFullClassificationField] = None,
        is_associated_with_app_item: Optional[bool] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        description: Optional[str] = None,
        size: Optional[int] = None,
        path_collection: Optional[FolderPathCollectionField] = None,
        created_by: Optional[UserMini] = None,
        modified_by: Optional[UserMini] = None,
        trashed_at: Optional[DateTime] = None,
        purged_at: Optional[DateTime] = None,
        content_created_at: Optional[DateTime] = None,
        content_modified_at: Optional[DateTime] = None,
        owned_by: Optional[UserMini] = None,
        shared_link: Optional[FolderSharedLinkField] = None,
        folder_upload_email: Optional[FolderFolderUploadEmailField] = None,
        parent: Optional[FolderMini] = None,
        item_status: Optional[FolderItemStatusField] = None,
        item_collection: Optional[Items] = None,
        sequence_id: Optional[str] = None,
        name: Optional[str] = None,
        etag: Optional[str] = None,
        type: FolderBaseTypeField = FolderBaseTypeField.FOLDER,
        **kwargs
    ):
        """
                :param id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting a folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folders/123`
        the `folder_id` is `123`.
                :type id: str
                :param has_collaborations: Specifies if this folder has any other collaborators., defaults to None
                :type has_collaborations: Optional[bool], optional
                :param is_externally_owned: Specifies if this folder is owned by a user outside of the
        authenticated enterprise., defaults to None
                :type is_externally_owned: Optional[bool], optional
                :param allowed_shared_link_access_levels: A list of access levels that are available
        for this folder.

        For some folders, like the root folder, this will always
        be an empty list as sharing is not allowed at that level., defaults to None
                :type allowed_shared_link_access_levels: Optional[List[FolderFullAllowedSharedLinkAccessLevelsField]], optional
                :param allowed_invitee_roles: A list of the types of roles that user can be invited at
        when sharing this folder., defaults to None
                :type allowed_invitee_roles: Optional[List[FolderFullAllowedInviteeRolesField]], optional
                :param is_accessible_via_shared_link: Specifies if the folder can be accessed
        with the direct shared link or a shared link
        to a parent folder., defaults to None
                :type is_accessible_via_shared_link: Optional[bool], optional
                :param can_non_owners_view_collaborators: Specifies if collaborators who are not owners
        of this folder are restricted from viewing other
        collaborations on this folder.

        It also restricts non-owners from inviting new
        collaborators., defaults to None
                :type can_non_owners_view_collaborators: Optional[bool], optional
                :param is_associated_with_app_item: This field will return true if the folder or any ancestor of the
        folder is associated with at least one app item. Note that this will
        return true even if the context user does not have access to the
        app item(s) associated with the folder., defaults to None
                :type is_associated_with_app_item: Optional[bool], optional
                :param created_at: The date and time when the folder was created. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: The date and time when the folder was last updated. This value may
        be `null` for some folders such as the root folder or the trash
        folder., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param size: The folder size in bytes.

        Be careful parsing this integer as its
        value can get very large., defaults to None
                :type size: Optional[int], optional
                :param trashed_at: The time at which this folder was put in the trash., defaults to None
                :type trashed_at: Optional[DateTime], optional
                :param purged_at: The time at which this folder is expected to be purged
        from the trash., defaults to None
                :type purged_at: Optional[DateTime], optional
                :param content_created_at: The date and time at which this folder was originally
        created., defaults to None
                :type content_created_at: Optional[DateTime], optional
                :param content_modified_at: The date and time at which this folder was last updated., defaults to None
                :type content_modified_at: Optional[DateTime], optional
                :param folder_upload_email: The `folder_upload_email` parameter is not `null` if one of the following options is **true**:

          * The **Allow uploads to this folder via email** and the **Only allow email uploads from collaborators in this folder** are [enabled for a folder in the Admin Console](https://support.box.com/hc/en-us/articles/360043697534-Upload-to-Box-Through-Email), and the user has at least **Upload** permissions granted.

          * The **Allow uploads to this folder via email** setting is enabled for a folder in the Admin Console, and the **Only allow email uploads from collaborators in this folder** setting is deactivated (unchecked).

        If the conditions are not met, the parameter will have the following value: `folder_upload_email: null`., defaults to None
                :type folder_upload_email: Optional[FolderFolderUploadEmailField], optional
                :param item_status: Defines if this item has been deleted or not.

        * `active` when the item has is not in the trash
        * `trashed` when the item has been moved to the trash but not deleted
        * `deleted` when the item has been permanently deleted., defaults to None
                :type item_status: Optional[FolderItemStatusField], optional
                :param name: The name of the folder., defaults to None
                :type name: Optional[str], optional
                :param etag: The HTTP `etag` of this folder. This can be used within some API
        endpoints in the `If-Match` and `If-None-Match` headers to only
        perform changes on the folder if (no) changes have happened., defaults to None
                :type etag: Optional[str], optional
                :param type: The value will always be `folder`., defaults to FolderBaseTypeField.FOLDER
                :type type: FolderBaseTypeField, optional
        """
        super().__init__(
            id=id,
            created_at=created_at,
            modified_at=modified_at,
            description=description,
            size=size,
            path_collection=path_collection,
            created_by=created_by,
            modified_by=modified_by,
            trashed_at=trashed_at,
            purged_at=purged_at,
            content_created_at=content_created_at,
            content_modified_at=content_modified_at,
            owned_by=owned_by,
            shared_link=shared_link,
            folder_upload_email=folder_upload_email,
            parent=parent,
            item_status=item_status,
            item_collection=item_collection,
            sequence_id=sequence_id,
            name=name,
            etag=etag,
            type=type,
            **kwargs
        )
        self.sync_state = sync_state
        self.has_collaborations = has_collaborations
        self.permissions = permissions
        self.tags = tags
        self.can_non_owners_invite = can_non_owners_invite
        self.is_externally_owned = is_externally_owned
        self.metadata = metadata
        self.is_collaboration_restricted_to_enterprise = (
            is_collaboration_restricted_to_enterprise
        )
        self.allowed_shared_link_access_levels = allowed_shared_link_access_levels
        self.allowed_invitee_roles = allowed_invitee_roles
        self.watermark_info = watermark_info
        self.is_accessible_via_shared_link = is_accessible_via_shared_link
        self.can_non_owners_view_collaborators = can_non_owners_view_collaborators
        self.classification = classification
        self.is_associated_with_app_item = is_associated_with_app_item



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError


class DevicePinnerTypeField(str, Enum):
    DEVICE_PINNER = 'device_pinner'


class DevicePinner(BaseObject):
    _discriminator = 'type', {'device_pinner'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[DevicePinnerTypeField] = None,
        owned_by: Optional[UserMini] = None,
        product_name: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this device pin., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `device_pinner`., defaults to None
        :type type: Optional[DevicePinnerTypeField], optional
        :param product_name: The type of device being pinned., defaults to None
        :type product_name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.owned_by = owned_by
        self.product_name = product_name



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.schemas.webhook_mini import WebhookMiniTypeField

from box_sdk_gen.schemas.webhook_mini import WebhookMiniTargetField

from box_sdk_gen.schemas.webhook_mini import WebhookMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class WebhookTriggersField(str, Enum):
    FILE_UPLOADED = 'FILE.UPLOADED'
    FILE_PREVIEWED = 'FILE.PREVIEWED'
    FILE_DOWNLOADED = 'FILE.DOWNLOADED'
    FILE_TRASHED = 'FILE.TRASHED'
    FILE_DELETED = 'FILE.DELETED'
    FILE_RESTORED = 'FILE.RESTORED'
    FILE_COPIED = 'FILE.COPIED'
    FILE_MOVED = 'FILE.MOVED'
    FILE_LOCKED = 'FILE.LOCKED'
    FILE_UNLOCKED = 'FILE.UNLOCKED'
    FILE_RENAMED = 'FILE.RENAMED'
    COMMENT_CREATED = 'COMMENT.CREATED'
    COMMENT_UPDATED = 'COMMENT.UPDATED'
    COMMENT_DELETED = 'COMMENT.DELETED'
    TASK_ASSIGNMENT_CREATED = 'TASK_ASSIGNMENT.CREATED'
    TASK_ASSIGNMENT_UPDATED = 'TASK_ASSIGNMENT.UPDATED'
    METADATA_INSTANCE_CREATED = 'METADATA_INSTANCE.CREATED'
    METADATA_INSTANCE_UPDATED = 'METADATA_INSTANCE.UPDATED'
    METADATA_INSTANCE_DELETED = 'METADATA_INSTANCE.DELETED'
    FOLDER_CREATED = 'FOLDER.CREATED'
    FOLDER_RENAMED = 'FOLDER.RENAMED'
    FOLDER_DOWNLOADED = 'FOLDER.DOWNLOADED'
    FOLDER_RESTORED = 'FOLDER.RESTORED'
    FOLDER_DELETED = 'FOLDER.DELETED'
    FOLDER_COPIED = 'FOLDER.COPIED'
    FOLDER_MOVED = 'FOLDER.MOVED'
    FOLDER_TRASHED = 'FOLDER.TRASHED'
    WEBHOOK_DELETED = 'WEBHOOK.DELETED'
    COLLABORATION_CREATED = 'COLLABORATION.CREATED'
    COLLABORATION_ACCEPTED = 'COLLABORATION.ACCEPTED'
    COLLABORATION_REJECTED = 'COLLABORATION.REJECTED'
    COLLABORATION_REMOVED = 'COLLABORATION.REMOVED'
    COLLABORATION_UPDATED = 'COLLABORATION.UPDATED'
    SHARED_LINK_DELETED = 'SHARED_LINK.DELETED'
    SHARED_LINK_CREATED = 'SHARED_LINK.CREATED'
    SHARED_LINK_UPDATED = 'SHARED_LINK.UPDATED'
    SIGN_REQUEST_COMPLETED = 'SIGN_REQUEST.COMPLETED'
    SIGN_REQUEST_DECLINED = 'SIGN_REQUEST.DECLINED'
    SIGN_REQUEST_EXPIRED = 'SIGN_REQUEST.EXPIRED'
    SIGN_REQUEST_SIGNER_EMAIL_BOUNCED = 'SIGN_REQUEST.SIGNER_EMAIL_BOUNCED'
    SIGN_REQUEST_SIGN_SIGNER_SIGNED = 'SIGN_REQUEST.SIGN_SIGNER_SIGNED'
    SIGN_REQUEST_SIGN_DOCUMENT_CREATED = 'SIGN_REQUEST.SIGN_DOCUMENT_CREATED'
    SIGN_REQUEST_SIGN_ERROR_FINALIZING = 'SIGN_REQUEST.SIGN_ERROR_FINALIZING'


class Webhook(WebhookMini):
    def __init__(
        self,
        *,
        created_by: Optional[UserMini] = None,
        created_at: Optional[DateTime] = None,
        address: Optional[str] = None,
        triggers: Optional[List[WebhookTriggersField]] = None,
        id: Optional[str] = None,
        type: Optional[WebhookMiniTypeField] = None,
        target: Optional[WebhookMiniTargetField] = None,
        **kwargs
    ):
        """
                :param created_at: A timestamp identifying the time that
        the webhook was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param address: The URL that is notified by this webhook., defaults to None
                :type address: Optional[str], optional
                :param triggers: An array of event names that this webhook is
        to be triggered for., defaults to None
                :type triggers: Optional[List[WebhookTriggersField]], optional
                :param id: The unique identifier for this webhook., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `webhook`., defaults to None
                :type type: Optional[WebhookMiniTypeField], optional
                :param target: The item that will trigger the webhook., defaults to None
                :type target: Optional[WebhookMiniTargetField], optional
        """
        super().__init__(id=id, type=type, target=target, **kwargs)
        self.created_by = created_by
        self.created_at = created_at
        self.address = address
        self.triggers = triggers
